unit Mail_pgm;

interface

uses
  DisplayUnit,
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, Menus, see, StdCtrls;

type
  TMailer = class(TForm)
    MainMenu1: TMainMenu;
    mConnect: TMenuItem;
    mSendMail: TMenuItem;
    mExit: TMenuItem;
    eMessage: TMemo;
    lUser: TLabel;
    lServer: TLabel;
    eHost: TEdit;
    eFrom: TEdit;
    lMessage: TLabel;
    lAttach: TLabel;
    lSubj: TLabel;
    eSubj: TEdit;
    eAttach: TEdit;
    eStatus: TMemo;
    lStatus: TLabel;
    lTo: TLabel;
    eTo: TEdit;
    procedure mExitClick(Sender: TObject);
    procedure mConnectClick(Sender: TObject);
    procedure mSendMailClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Mailer: TMailer;
  D1, D2, D3 : Integer;
  Code : Integer;

implementation

{$R *.DFM}

procedure TMailer.mExitClick(Sender: TObject);
begin
  seeClose;
  Application.Terminate;
end;

procedure TMailer.mConnectClick(Sender: TObject);
var
  Code : Integer;
  HostPtr : PChar;
  FromPtr : PChar;
  NullPtr : PChar;
  LogPtr  : PChar;
begin
  {show SEE version}
  Code := seeStatistics(SEE_GET_VERSION);
  D3 := $0F AND Code;  Code := Code SHR 4;
  D2 := $0F AND Code;  Code := Code SHR 4;
  D1 := $0F AND Code;
  DisplayLine(Mailer.eStatus,'SMTP/POP3 Email Engine Version '
            + Chr(48 + D1)
            + '.' + Chr(48 + D2)
            + '.' + Chr(48 + D3));
  {define log file}
  GetMem(LogPtr,32); StrPCopy(LogPtr, 'MAILER.LOG');
  seeStringParam(SEE_LOG_FILE, LogPtr); FreeMem(LogPtr, 32);
  {do we have all necessary parameters ?}
  if Length(eHost.Text) = 0 then
    begin
      DisplayLine(Mailer.eStatus,'SMTP Host is missing');
      exit;
    end;
  if Length(eFrom.Text) = 0 then
    begin
      DisplayLine(Mailer.eStatus,'From address is missing');
      exit;
    end;
  {validate From email address}
  GetMem(FromPtr, 64); StrPCopy(FromPtr, eFrom.Text);
  Code := seeVerifyFormat(FromPtr);
  if Code < 0 then
    begin
      DisplayString(Mailer.eStatus,'ERROR1:');
      DisplayError(Mailer.eStatus, Code);
      seeClose;
      FreeMem(FromPtr,64);
      exit;
    end;
  {allocate remaining buffers}
  GetMem(HostPtr, 64); StrPCopy(HostPtr, eHost.Text);
  GetMem(NullPtr, 4);  StrPCopy(NullPtr, '');
  {connect to POP3 server}
  DisplayLine(Mailer.eStatus,Format('Connecting to %s',[StrPas(HostPtr)]));
  Code := seeSmtpConnect(HostPtr, FromPtr, NullPtr);
  {free buffers}
  FreeMem(HostPtr,64); FreeMem(FromPtr,64);
  {any errors ?}
  If Code < 0 then
    begin
      DisplayString(Mailer.eStatus,'ERROR2:');
      DisplayError(Mailer.eStatus, Code);
      seeClose;
      exit;
    end;
  {ready to check mail}
  DisplayLine(Mailer.eStatus,'Connected. Ready to SendMail.');
  mConnect.Enabled := false;
  mSendmail.Enabled := true;
end;

procedure TMailer.mSendMailClick(Sender: TObject);
var
  Code  : Integer;
  ToPtr : PChar;
  MsgSize : Integer;
  SubjPtr : PChar;
  MsgPtr  : PChar;
  AttPtr  : PChar;
  NullPtr : PChar;
begin
  {do we have all necessary parameters ?}
  if Length(eTo.Text) = 0 then
    begin
      DisplayLine(Mailer.eStatus,'To address is missing');
      exit;
    end;
  {validate To email address}
  GetMem(ToPtr, 64); StrPCopy(ToPtr, eTo.Text);
  Code := seeVerifyFormat(ToPtr);
  if Code = 0 then
    begin
      DisplayError(eStatus, Code);
      seeClose;
      FreeMem(ToPtr,64);
      exit;
    end;
  {allocate Message, Subject, & Attach pointers}
  GetMem(SubjPtr, 64); StrPCopy(SubjPtr, eSubj.Text);
  MsgSize := Length(eMessage.Text);
  GetMem(MsgPtr, MsgSize+1); StrPCopy(MsgPtr, eMessage.Text);
  GetMem(AttPtr, 64); StrPCopy(AttPtr, eAttach.Text);
  GetMem(NullPtr,4); StrPCopy(NullPtr, '');
  {send the email}
  mSendmail.Enabled := false;
  DisplayLine(Mailer.eStatus,'Sending mail...');
  Code := seeSendEmail(ToPtr,NullPtr,NullPtr,SubjPtr,MsgPtr,AttPtr);
  {free buffers}
  FreeMem(ToPtr,64); FreeMem(SubjPtr,64); FreeMem(MsgPtr,MsgSize+1);
  FreeMem(AttPtr,64); FreeMem(NullPtr,4);
  {any errors ?}
  If Code < 0 then
    begin
      DisplayError(eMessage, Code);
      seeClose;
      exit;
    end;
  {ready to check mail}
  DisplayLine(Mailer.eStatus,'Email has been sent...');
  mSendmail.Enabled := true;
end;

end.
